==> pydantic_dydb-0.1.1.tar.gz: pydantic_dydb-0.1.1/pydantic_dydb/initialization.py <==
from typing import Any, Optional

import orjson

from .aws import DynamoDB
from .credentials_managers import CredentialManagerBase


class _TableData:
    __slots__ = (
        "table_name",
        "region",
        "dydb",
        "hash_key",
        "range_key",
    )

    def __init__(self):
        self.table_name: str = None
        self.region: str = None
        self.table_name: str
        self.region: str
        self.hash_key: str = None
        self.range_key: Optional[str] = None
        self.dydb: Any


__table_data = _TableData()


def get_table_data():
    return __table_data


def init(
    *,
    table_name: str,
    region_name: str,
    credential_manager: CredentialManagerBase,
    endpoint: str = None,
):
    assert isinstance(
        table_name, str
    ), f"expected {table_name=} to be type str, instead is {type(table_name)}"

    assert isinstance(
        region_name, str
    ), f"expected {region_name=}  to be type str is {type(region_name)}"

    assert isinstance(
        credential_manager, CredentialManagerBase
    ), f"expected {credential_manager=} to be object of inherited from CredentialManagerBase"

    if endpoint is None:
        endpoint = f"https://dynamodb.{region_name}.amazonaws.com"

    dydb = DynamoDB(
        table_name=table_name,
        region=region_name,
        credential_manager=credential_manager,
        endpoint=endpoint,
    )

    table = dydb.describe_table()
    table_json = orjson.loads(table)
    for attribute in table_json["Table"]["KeySchema"]:
        key_type = attribute["KeyType"]
        attribute_name = attribute["AttributeName"]

        if key_type == "HASH":
            __table_data.hash_key = attribute_name
        if key_type == "RANGE":
            __table_data.range_key = attribute_name

    __table_data.table_name = table_name
    __table_data.region = region_name
    __table_data.dydb = dydb

==> pydantic_dydb-0.1.2.tar.gz: pydantic_dydb-0.1.2/pydantic_dydb/initialization.py <==
from typing import Any, Optional

import orjson

from .aws import DynamoDB
from .credentials_managers import CredentialManagerBase


class _TableData:
    __slots__ = ("table_name", "region", "dydb", "hash_key", "range_key", "delimiter")

    def __init__(self):
        self.table_name: str = None
        self.region: str = None
        self.table_name: str
        self.region: str
        self.hash_key: str = None
        self.range_key: Optional[str] = None
        self.dydb: DynamoDB
        self.delimiter: str


__table_data = _TableData()


def get_table_data() -> _TableData:
    return __table_data


def init(
    *,
    table_name: str,
    region_name: str,
    credential_manager: CredentialManagerBase,
    endpoint: str = None,
    delimiter: str = ";",
):
    assert isinstance(
        table_name, str
    ), f"expected {table_name=} to be type str, instead is {type(table_name)}"

    assert isinstance(
        region_name, str
    ), f"expected {region_name=}  to be type str is {type(region_name)}"

    assert isinstance(
        credential_manager, CredentialManagerBase
    ), f"expected {credential_manager=} to be object of inherited from CredentialManagerBase"

    assert isinstance(
        delimiter, str
    ), f"expected {delimiter=} to be type str, instead is {type(delimiter)}"

    if endpoint is None:
        endpoint = f"https://dynamodb.{region_name}.amazonaws.com"

    dydb = DynamoDB(
        table_name=table_name,
        region=region_name,
        credential_manager=credential_manager,
        endpoint=endpoint,
    )

    table = dydb.describe_table()
    table_json = orjson.loads(table)
    for attribute in table_json["Table"]["KeySchema"]:
        key_type = attribute["KeyType"]
        attribute_name = attribute["AttributeName"]

        if key_type == "HASH":
            __table_data.hash_key = attribute_name
        if key_type == "RANGE":
            __table_data.range_key = attribute_name

    __table_data.table_name = table_name
    __table_data.region = region_name
    __table_data.dydb = dydb
    __table_data.delimiter = delimiter
